#[non_exhaustive]pub enum ReqwestStreamOutcome {
InProgress,
Completed,
Aborted,
Failed,
}Available on crate features
arrow or csv or json or protobuf only.Expand description
How a stream ended.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InProgress
Still running; reported by interim progress only.
Completed
Reached the end of the body with no errors.
Aborted
Ended early because the other side of the stream went away.
Failed
Reached its end, but at least one error was reported along the way.
Implementations