StreamBodyRequest

Trait StreamBodyRequest 

pub trait StreamBodyRequest {
    // Required method
    fn stream_body(self, body: ReqwestStreamBody) -> RequestBuilder;
}
Available on crate features arrow or csv or json or protobuf only.
Sets a streamed body and its Content-Type on a request in one step.

Required Methods

fn stream_body(self, body: ReqwestStreamBody) -> RequestBuilder

Sets body as the request body, along with its Content-Type.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl StreamBodyRequest for RequestBuilder

Implementors